@@ -1,8 +1,10 @@
 
+import logging
 import msmart.crc8 as crc8
 
-VERSION = '0.1.12'
+VERSION = '0.1.13'
 
+_LOGGER = logging.getLogger(__name__)
 
 class base_command:
 
@@ -17,8 +19,22 @@ class base_command:
             0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
             # request is 0x03; setting is 0x02
             0x03,
-            # request is 0x41; setting is 0x40
-            0x41, 0x81, 0x00, 0xff, 0x03, 0xff, 0x00, 0x02, 
+            # Byte0 - Data request/response type: 0x41 - check status; 0x40 - Set up
+            0x41, 
+            # Byte1 
+            0x00, 
+            # Byte2 - operational_mode
+            0x00, 
+            # Byte3
+            0xff, 
+            # Byte4
+            0x03, 
+            # Byte5
+            0xff, 
+            # Byte6
+            0x00,
+            # Byte7 - Room Temperature Request: 0x02 - indoor_temperature, 0x03 - outdoor_temperature
+            0x02, 
             0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
             0x00, 0x00, 0x00, 0x00,
             # 
@@ -40,15 +56,16 @@ class set_command(base_command):
         base_command.__init__(self, device_type)
         self.data[0x01] = 0x23
         self.data[0x09] = 0x02
+        # Set up Mode
         self.data[0x0a] = 0x40
         self.data.extend(bytearray([0x00, 0x00, 0x00]))
 
     @property
-    def audible_feedback(self):
+    def prompt_tone(self):
         return self.data[0x0b] & 0x42
 
-    @audible_feedback.setter
-    def audible_feedback(self, feedback_anabled: bool):
+    @prompt_tone.setter
+    def prompt_tone(self, feedback_anabled: bool):
         self.data[0x0b] &= ~ 0x42  # Clear the audible bits
         self.data[0x0b] |= 0x42 if feedback_anabled else 0
 
@@ -117,10 +134,9 @@ class set_command(base_command):
 class appliance_response:
 
     def __init__(self, data: bytearray):
-        # The response data from the appliance includes a packet header which we don't want
+        # The response data from the appliance includes a packet header which we don't want 
         self.data = data[0xa:]
-        if(__debug__):
-            print("Appliance response data: {}".format(self.data.hex()))
+        _LOGGER.debug("Appliance response data: {}".format(self.data.hex()))
 
     # Byte 0x01
 
