@@ -1,4 +1,5 @@
 
+import logging
 from enum import Enum
 
 import msmart.crc8 as crc8
@@ -8,7 +9,9 @@ from msmart.command import base_command as request_status_command
 from msmart.command import set_command
 from msmart.packet_builder import packet_builder
 
-VERSION = '0.1.12'
+VERSION = '0.1.13'
+
+_LOGGER = logging.getLogger(__name__)
 
 def convert_device_id_hex(device_id: int):
     hex_string = hex(device_id)[2:]
@@ -106,7 +109,7 @@ class air_conditioning_device(device):
                 value = 101
             if(value in air_conditioning_device.fan_speed_enum._value2member_map_):
                 return air_conditioning_device.fan_speed_enum(value)
-            print("Unknown Fan Speed: {}".format(value))
+            _LOGGER.debug("Unknown Fan Speed: {}".format(value))
             return air_conditioning_device.fan_speed_enum.Auto
 
     class operational_mode_enum(Enum):
@@ -124,7 +127,7 @@ class air_conditioning_device(device):
         def get(value):
             if(value in air_conditioning_device.operational_mode_enum._value2member_map_):
                 return air_conditioning_device.operational_mode_enum(value)
-            print("Unknown Operational Mode: {}".format(value))
+            _LOGGER.debug("Unknown Operational Mode: {}".format(value))
             return air_conditioning_device.operational_mode_enum.fan_only
 
     class swing_mode_enum(Enum):
@@ -141,13 +144,13 @@ class air_conditioning_device(device):
         def get(value):
             if(value in air_conditioning_device.swing_mode_enum._value2member_map_):
                 return air_conditioning_device.swing_mode_enum(value)
-            print("Unknown Swing Mode: {}".format(value))
+            _LOGGER.debug("Unknown Swing Mode: {}".format(value))
             return air_conditioning_device.swing_mode_enum.Off
 
     def __init__(self, device_ip: str, device_id: str):
         super().__init__(device_ip, convert_device_id_int(device_id))
 
-        self._audible_feedback = False
+        self._prompt_tone = False
         self._power_state = False
         self._target_temperature = 17
         self._operational_mode = air_conditioning_device.operational_mode_enum.auto
@@ -168,15 +171,17 @@ class air_conditioning_device(device):
 
         data = pkt_builder.finalize()
         data = self._lan_service.appliance_transparent_send(data)
-        response = appliance_response(data)
-        self._defer_update = False
-        self.update(response)
+        _LOGGER.debug("refresh - Recieved from {}, {}: {}".format(self.ip, self.id, data.hex()))
+        if len(data) > 0:
+            response = appliance_response(data)
+            self._defer_update = False
+            self.update(response)
 
     def apply(self):
         self._updating = True
         try:
             cmd = set_command(self.type)
-            cmd.audible_feedback = self._audible_feedback
+            cmd.prompt_tone = self._prompt_tone
             cmd.power_state = self._power_state
             cmd.target_temperature = self._target_temperature
             cmd.operational_mode = self._operational_mode.value
@@ -190,9 +195,11 @@ class air_conditioning_device(device):
 
             data = pkt_builder.finalize()
             data = self._lan_service.appliance_transparent_send(data)
-            response = appliance_response(data)
-            if not self._defer_update:
-                self.update(response)
+            _LOGGER.debug("apply - Recieved from {}, {}: {}".format(self.ip, self.id, data.hex()))
+            if len(data) > 0:
+                response = appliance_response(data)
+                if not self._defer_update:
+                    self.update(response)
         finally:
             self._updating = False
             self._defer_update = False
@@ -214,14 +221,14 @@ class air_conditioning_device(device):
         self._timer_off = res.off_timer
 
     @property
-    def audible_feedback(self):
-        return self._audible_feedback
+    def prompt_tone(self):
+        return self._prompt_tone
 
-    @audible_feedback.setter
-    def audible_feedback(self, feedback: bool):
+    @prompt_tone.setter
+    def prompt_tone(self, feedback: bool):
         if self._updating:
             self._defer_update = True
-        self._audible_feedback = feedback
+        self._prompt_tone = feedback
 
     @property
     def power_state(self):
@@ -322,21 +329,22 @@ class unknown_device(device):
 
         data = pkt_builder.finalize()
         data = self._lan_service.appliance_transparent_send(self.id, data)
-        response = appliance_response(data)
-        print("Decoded Data: {}".format({
-            'audible_feedback': response.audible_feedback,
-            'target_temperature': response.target_temperature,
-            'indoor_temperature': response.indoor_temperature,
-            'outdoor_temperature': response.outdoor_temperature,
-            'operational_mode': response.operational_mode,
-            'fan_speed': response.fan_speed,
-            'swing_mode': response.swing_mode,
-            'eco_mode': response.eco_mode,
-            'turbo_mode': response.turbo_mode
-        }))
+        if len(data) > 0:
+            response = appliance_response(data)
+            _LOGGER.debug("Decoded Data: {}".format({
+                'prompt_tone': response.prompt_tone,
+                'target_temperature': response.target_temperature,
+                'indoor_temperature': response.indoor_temperature,
+                'outdoor_temperature': response.outdoor_temperature,
+                'operational_mode': response.operational_mode,
+                'fan_speed': response.fan_speed,
+                'swing_mode': response.swing_mode,
+                'eco_mode': response.eco_mode,
+                'turbo_mode': response.turbo_mode
+            }))
 
     def apply(self):
-        print("Cannot apply, device not fully supported yet")
+        _LOGGER.debug("Cannot apply, device not fully supported yet")
 
 
 class dehumidifier_device(unknown_device):
