@@ -1,3 +1,4 @@
+import logging
 import requests
 import datetime
 import json
@@ -9,8 +10,9 @@ from msmart.security import security
 # The Midea cloud client is by far the more obscure part of this library, and without some serious reverse engineering
 # this would not have been possible. Thanks Yitsushi for the ruby implementation. This is an adaptation to Python 3
 
-VERSION = '0.1.12'
+VERSION = '0.1.13'
 
+_LOGGER = logging.getLogger(__name__)
 
 class lan:
     def __init__(self, device_ip, device_id):
@@ -24,7 +26,7 @@ class lan:
     def request(self, message):
         # Create a TCP/IP socket
         sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-        sock.settimeout(5)
+        sock.settimeout(8)
 
         # Connect the Device
         device_address = (self.device_ip, self.device_port)
@@ -32,13 +34,17 @@ class lan:
 
         try:
             # Send data
+            _LOGGER.debug("Sending to %s:%s %s." %(self.device_ip, self.device_port, message.hex()))
             sock.sendall(message)
 
             # Received data
-            response = sock.recv(256)
+            response = sock.recv(512)
+        except socket.timeout:
+            _LOGGER.debug("Connect the Device %s:%s TimeOut." %(self.device_ip, self.device_port))
+            return None
         finally:
             sock.close()
-        
+        _LOGGER.debug("Received from %s:%s %s." %(self.device_ip, self.device_port, message.hex()))
         return response
 
     def encode(self, data: bytearray):
@@ -62,8 +68,5 @@ class lan:
         encoded = self.encode(data)
         response = bytearray(self.request(data))[40:88]
         reply = self.decode(self.security.aes_decrypt(response))
-
-        if(__debug__):
-            print("Recieved from {}: {}".format(id, reply.hex()))
         return reply
 
